contract

Attribute Macro contract 

#[contract]
contract attribute macro

contract should be applied to a trait. Сurrently, only fn items are supported for parsing and presense of other types of items (like consts and associated types) will trigger compile errors, as well as presence of generic parameters (though it’s planned to support trait level type generics in the future).